'''_179.py

ElasticModulusOrthotropicComponents
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_ELASTIC_MODULUS_ORTHOTROPIC_COMPONENTS = python_net_import('SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses.FullFEReporting', 'ElasticModulusOrthotropicComponents')


__docformat__ = 'restructuredtext en'
__all__ = ('ElasticModulusOrthotropicComponents',)


class ElasticModulusOrthotropicComponents(_0.APIBase):
    '''ElasticModulusOrthotropicComponents

    This is a mastapy class.
    '''

    TYPE = _ELASTIC_MODULUS_ORTHOTROPIC_COMPONENTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElasticModulusOrthotropicComponents.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def ex(self) -> 'float':
        '''float: 'EX' is the original name of this property.'''

        return self.wrapped.EX

    @ex.setter
    def ex(self, value: 'float'):
        self.wrapped.EX = float(value) if value else 0.0

    @property
    def ey(self) -> 'float':
        '''float: 'EY' is the original name of this property.'''

        return self.wrapped.EY

    @ey.setter
    def ey(self, value: 'float'):
        self.wrapped.EY = float(value) if value else 0.0

    @property
    def ez(self) -> 'float':
        '''float: 'EZ' is the original name of this property.'''

        return self.wrapped.EZ

    @ez.setter
    def ez(self, value: 'float'):
        self.wrapped.EZ = float(value) if value else 0.0



'''_2550.py

RigidlyConnectedComponentGroupSystemDeflection
'''


from typing import List

from mastapy.math_utility import _1299
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.system_deflections import _2417
from mastapy.system_model.analyses_and_results import _2359
from mastapy._internal.python_net import python_net_import

_RIGIDLY_CONNECTED_COMPONENT_GROUP_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Reporting', 'RigidlyConnectedComponentGroupSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('RigidlyConnectedComponentGroupSystemDeflection',)


class RigidlyConnectedComponentGroupSystemDeflection(_2359.DesignEntityGroupAnalysis):
    '''RigidlyConnectedComponentGroupSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _RIGIDLY_CONNECTED_COMPONENT_GROUP_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RigidlyConnectedComponentGroupSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def mass_properties(self) -> '_1299.MassProperties':
        '''MassProperties: 'MassProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1299.MassProperties)(self.wrapped.MassProperties) if self.wrapped.MassProperties else None

    @property
    def components(self) -> 'List[_2417.ComponentSystemDeflection]':
        '''List[ComponentSystemDeflection]: 'Components' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Components, constructor.new(_2417.ComponentSystemDeflection))
        return value



'''_5808.py

HarmonicAnalysisResultsPropertyAccessor
'''


from typing import List

from mastapy.system_model.analyses_and_results.harmonic_analyses.reportable_property_results import _5821, _5814
from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_HARMONIC_ANALYSIS_RESULTS_PROPERTY_ACCESSOR = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.ReportablePropertyResults', 'HarmonicAnalysisResultsPropertyAccessor')


__docformat__ = 'restructuredtext en'
__all__ = ('HarmonicAnalysisResultsPropertyAccessor',)


class HarmonicAnalysisResultsPropertyAccessor(_0.APIBase):
    '''HarmonicAnalysisResultsPropertyAccessor

    This is a mastapy class.
    '''

    TYPE = _HARMONIC_ANALYSIS_RESULTS_PROPERTY_ACCESSOR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'HarmonicAnalysisResultsPropertyAccessor.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def excitations(self) -> 'List[_5821.SingleWhineAnalysisResultsPropertyAccessor]':
        '''List[SingleWhineAnalysisResultsPropertyAccessor]: 'Excitations' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Excitations, constructor.new(_5821.SingleWhineAnalysisResultsPropertyAccessor))
        return value

    @property
    def orders_for_combined_excitations(self) -> 'List[_5814.ResultsForOrderIncludingNodes]':
        '''List[ResultsForOrderIncludingNodes]: 'OrdersForCombinedExcitations' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.OrdersForCombinedExcitations, constructor.new(_5814.ResultsForOrderIncludingNodes))
        return value

    @property
    def orders_for_combined_excitations_from_same_parts(self) -> 'List[_5814.ResultsForOrderIncludingNodes]':
        '''List[ResultsForOrderIncludingNodes]: 'OrdersForCombinedExcitationsFromSameParts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.OrdersForCombinedExcitationsFromSameParts, constructor.new(_5814.ResultsForOrderIncludingNodes))
        return value



'''_157.py

FEEntityGroup
'''


from typing import Generic, TypeVar

from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_FE_ENTITY_GROUP = python_net_import('SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses', 'FEEntityGroup')


__docformat__ = 'restructuredtext en'
__all__ = ('FEEntityGroup',)


T = TypeVar('T')


class FEEntityGroup(_0.APIBase, Generic[T]):
    '''FEEntityGroup

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _FE_ENTITY_GROUP

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FEEntityGroup.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.'''

        return self.wrapped.Name

    @name.setter
    def name(self, value: 'str'):
        self.wrapped.Name = str(value) if value else None

    @property
    def number_of_items(self) -> 'int':
        '''int: 'NumberOfItems' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfItems



'''_280.py

AGMAToleranceStandard
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_AGMA_TOLERANCE_STANDARD = python_net_import('SMT.MastaAPI.Gears', 'AGMAToleranceStandard')


__docformat__ = 'restructuredtext en'
__all__ = ('AGMAToleranceStandard',)


class AGMAToleranceStandard(Enum):
    '''AGMAToleranceStandard

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _AGMA_TOLERANCE_STANDARD

    __hash__ = None

    AGMA_20151A01 = 0
    AGMA_2000A88 = 1
    ANSIAGMA_ISO_13281B14 = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


AGMAToleranceStandard.__setattr__ = __enum_setattr
AGMAToleranceStandard.__delattr__ = __enum_delattr



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._379 import KlingelnbergConicalMeshSingleFlankRating
    from ._380 import KlingelnbergConicalRateableMesh
    from ._381 import KlingelnbergCycloPalloidConicalGearSingleFlankRating
    from ._382 import KlingelnbergCycloPalloidHypoidGearSingleFlankRating
    from ._383 import KlingelnbergCycloPalloidHypoidMeshSingleFlankRating
    from ._384 import KlingelnbergCycloPalloidSpiralBevelMeshSingleFlankRating



'''_6234.py

BeltConnectionCriticalSpeedAnalysis
'''


from mastapy.system_model.connections_and_sockets import _1977, _1982
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.static_loads import _6502, _6535
from mastapy.system_model.analyses_and_results.critical_speed_analyses import _6292
from mastapy._internal.python_net import python_net_import

_BELT_CONNECTION_CRITICAL_SPEED_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.CriticalSpeedAnalyses', 'BeltConnectionCriticalSpeedAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltConnectionCriticalSpeedAnalysis',)


class BeltConnectionCriticalSpeedAnalysis(_6292.InterMountableComponentConnectionCriticalSpeedAnalysis):
    '''BeltConnectionCriticalSpeedAnalysis

    This is a mastapy class.
    '''

    TYPE = _BELT_CONNECTION_CRITICAL_SPEED_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BeltConnectionCriticalSpeedAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_1977.BeltConnection':
        '''BeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1977.BeltConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BeltConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6502.BeltConnectionLoadCase':
        '''BeltConnectionLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _6502.BeltConnectionLoadCase.TYPE not in self.wrapped.ConnectionLoadCase.__class__.__mro__:
            raise CastException('Failed to cast connection_load_case to BeltConnectionLoadCase. Expected: {}.'.format(self.wrapped.ConnectionLoadCase.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionLoadCase.__class__)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None



'''_5592.py

RollingRingCompoundHarmonicAnalysisOfSingleExcitation
'''


from typing import List

from mastapy.system_model.part_model.couplings import _2303
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation import _5464
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation.compound import _5539
from mastapy._internal.python_net import python_net_import

_ROLLING_RING_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation.Compound', 'RollingRingCompoundHarmonicAnalysisOfSingleExcitation')


__docformat__ = 'restructuredtext en'
__all__ = ('RollingRingCompoundHarmonicAnalysisOfSingleExcitation',)


class RollingRingCompoundHarmonicAnalysisOfSingleExcitation(_5539.CouplingHalfCompoundHarmonicAnalysisOfSingleExcitation):
    '''RollingRingCompoundHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    '''

    TYPE = _ROLLING_RING_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollingRingCompoundHarmonicAnalysisOfSingleExcitation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2303.RollingRing':
        '''RollingRing: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2303.RollingRing)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_5464.RollingRingHarmonicAnalysisOfSingleExcitation]':
        '''List[RollingRingHarmonicAnalysisOfSingleExcitation]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_5464.RollingRingHarmonicAnalysisOfSingleExcitation))
        return value

    @property
    def planetaries(self) -> 'List[RollingRingCompoundHarmonicAnalysisOfSingleExcitation]':
        '''List[RollingRingCompoundHarmonicAnalysisOfSingleExcitation]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(RollingRingCompoundHarmonicAnalysisOfSingleExcitation))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_5464.RollingRingHarmonicAnalysisOfSingleExcitation]':
        '''List[RollingRingHarmonicAnalysisOfSingleExcitation]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_5464.RollingRingHarmonicAnalysisOfSingleExcitation))
        return value



'''_198.py

CMSElementFaceGroupOfAllFreeFaces
'''


from mastapy.nodal_analysis.component_mode_synthesis import _197
from mastapy._internal.python_net import python_net_import

_CMS_ELEMENT_FACE_GROUP_OF_ALL_FREE_FACES = python_net_import('SMT.MastaAPI.NodalAnalysis.ComponentModeSynthesis', 'CMSElementFaceGroupOfAllFreeFaces')


__docformat__ = 'restructuredtext en'
__all__ = ('CMSElementFaceGroupOfAllFreeFaces',)


class CMSElementFaceGroupOfAllFreeFaces(_197.CMSElementFaceGroup):
    '''CMSElementFaceGroupOfAllFreeFaces

    This is a mastapy class.
    '''

    TYPE = _CMS_ELEMENT_FACE_GROUP_OF_ALL_FREE_FACES

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CMSElementFaceGroupOfAllFreeFaces.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1070.py

DIN3967SystemOfGearFits
'''


from mastapy.gears.gear_designs.cylindrical import _978, _979
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_DIN3967_SYSTEM_OF_GEAR_FITS = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical.AccuracyAndTolerances', 'DIN3967SystemOfGearFits')


__docformat__ = 'restructuredtext en'
__all__ = ('DIN3967SystemOfGearFits',)


class DIN3967SystemOfGearFits(_0.APIBase):
    '''DIN3967SystemOfGearFits

    This is a mastapy class.
    '''

    TYPE = _DIN3967_SYSTEM_OF_GEAR_FITS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DIN3967SystemOfGearFits.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def tooth_thickness_reduction_allowance(self) -> '_978.DIN3967AllowanceSeries':
        '''DIN3967AllowanceSeries: 'ToothThicknessReductionAllowance' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.ToothThicknessReductionAllowance)
        return constructor.new(_978.DIN3967AllowanceSeries)(value) if value else None

    @tooth_thickness_reduction_allowance.setter
    def tooth_thickness_reduction_allowance(self, value: '_978.DIN3967AllowanceSeries'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ToothThicknessReductionAllowance = value

    @property
    def tooth_thickness_tolerance(self) -> '_979.DIN3967ToleranceSeries':
        '''DIN3967ToleranceSeries: 'ToothThicknessTolerance' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.ToothThicknessTolerance)
        return constructor.new(_979.DIN3967ToleranceSeries)(value) if value else None

    @tooth_thickness_tolerance.setter
    def tooth_thickness_tolerance(self, value: '_979.DIN3967ToleranceSeries'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ToothThicknessTolerance = value



'''_1806.py

Grease
'''


from mastapy._internal import constructor
from mastapy.bearings.bearing_results.rolling.skf_module import _1815
from mastapy._internal.python_net import python_net_import

_GREASE = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling.SkfModule', 'Grease')


__docformat__ = 'restructuredtext en'
__all__ = ('Grease',)


class Grease(_1815.SKFCalculationResult):
    '''Grease

    This is a mastapy class.
    '''

    TYPE = _GREASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'Grease.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def relubrication_interval(self) -> 'float':
        '''float: 'RelubricationInterval' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RelubricationInterval

    @property
    def grease_life(self) -> 'float':
        '''float: 'GreaseLife' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.GreaseLife



'''_1955.py

CriticalSpeedAnalysisViewable
'''


from mastapy.system_model.drawing import _1963
from mastapy._internal.python_net import python_net_import

_CRITICAL_SPEED_ANALYSIS_VIEWABLE = python_net_import('SMT.MastaAPI.SystemModel.Drawing', 'CriticalSpeedAnalysisViewable')


__docformat__ = 'restructuredtext en'
__all__ = ('CriticalSpeedAnalysisViewable',)


class CriticalSpeedAnalysisViewable(_1963.RotorDynamicsViewable):
    '''CriticalSpeedAnalysisViewable

    This is a mastapy class.
    '''

    TYPE = _CRITICAL_SPEED_ANALYSIS_VIEWABLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CriticalSpeedAnalysisViewable.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_2003.py

ShaftSocket
'''


from mastapy.system_model.connections_and_sockets import _1985
from mastapy._internal.python_net import python_net_import

_SHAFT_SOCKET = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets', 'ShaftSocket')


__docformat__ = 'restructuredtext en'
__all__ = ('ShaftSocket',)


class ShaftSocket(_1985.CylindricalSocket):
    '''ShaftSocket

    This is a mastapy class.
    '''

    TYPE = _SHAFT_SOCKET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ShaftSocket.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6954 import AbstractAssemblyAdvancedSystemDeflection
    from ._6955 import AbstractShaftAdvancedSystemDeflection
    from ._6956 import AbstractShaftOrHousingAdvancedSystemDeflection
    from ._6957 import AbstractShaftToMountableComponentConnectionAdvancedSystemDeflection
    from ._6958 import AdvancedSystemDeflection
    from ._6959 import AdvancedSystemDeflectionOptions
    from ._6960 import AdvancedSystemDeflectionSubAnalysis
    from ._6961 import AGMAGleasonConicalGearAdvancedSystemDeflection
    from ._6962 import AGMAGleasonConicalGearMeshAdvancedSystemDeflection
    from ._6963 import AGMAGleasonConicalGearSetAdvancedSystemDeflection
    from ._6964 import AssemblyAdvancedSystemDeflection
    from ._6965 import BearingAdvancedSystemDeflection
    from ._6966 import BeltConnectionAdvancedSystemDeflection
    from ._6967 import BeltDriveAdvancedSystemDeflection
    from ._6968 import BevelDifferentialGearAdvancedSystemDeflection
    from ._6969 import BevelDifferentialGearMeshAdvancedSystemDeflection
    from ._6970 import BevelDifferentialGearSetAdvancedSystemDeflection
    from ._6971 import BevelDifferentialPlanetGearAdvancedSystemDeflection
    from ._6972 import BevelDifferentialSunGearAdvancedSystemDeflection
    from ._6973 import BevelGearAdvancedSystemDeflection
    from ._6974 import BevelGearMeshAdvancedSystemDeflection
    from ._6975 import BevelGearSetAdvancedSystemDeflection
    from ._6976 import BoltAdvancedSystemDeflection
    from ._6977 import BoltedJointAdvancedSystemDeflection
    from ._6978 import ClutchAdvancedSystemDeflection
    from ._6979 import ClutchConnectionAdvancedSystemDeflection
    from ._6980 import ClutchHalfAdvancedSystemDeflection
    from ._6981 import CoaxialConnectionAdvancedSystemDeflection
    from ._6982 import ComponentAdvancedSystemDeflection
    from ._6983 import ConceptCouplingAdvancedSystemDeflection
    from ._6984 import ConceptCouplingConnectionAdvancedSystemDeflection
    from ._6985 import ConceptCouplingHalfAdvancedSystemDeflection
    from ._6986 import ConceptGearAdvancedSystemDeflection
    from ._6987 import ConceptGearMeshAdvancedSystemDeflection
    from ._6988 import ConceptGearSetAdvancedSystemDeflection
    from ._6989 import ConicalGearAdvancedSystemDeflection
    from ._6990 import ConicalGearMeshAdvancedSystemDeflection
    from ._6991 import ConicalGearSetAdvancedSystemDeflection
    from ._6992 import ConnectionAdvancedSystemDeflection
    from ._6993 import ConnectorAdvancedSystemDeflection
    from ._6994 import ContactChartPerToothPass
    from ._6995 import CouplingAdvancedSystemDeflection
    from ._6996 import CouplingConnectionAdvancedSystemDeflection
    from ._6997 import CouplingHalfAdvancedSystemDeflection
    from ._6998 import CVTAdvancedSystemDeflection
    from ._6999 import CVTBeltConnectionAdvancedSystemDeflection
    from ._7000 import CVTPulleyAdvancedSystemDeflection
    from ._7001 import CycloidalAssemblyAdvancedSystemDeflection
    from ._7002 import CycloidalDiscAdvancedSystemDeflection
    from ._7003 import CycloidalDiscCentralBearingConnectionAdvancedSystemDeflection
    from ._7004 import CycloidalDiscPlanetaryBearingConnectionAdvancedSystemDeflection
    from ._7005 import CylindricalGearAdvancedSystemDeflection
    from ._7006 import CylindricalGearMeshAdvancedSystemDeflection
    from ._7007 import CylindricalGearSetAdvancedSystemDeflection
    from ._7008 import CylindricalMeshedGearAdvancedSystemDeflection
    from ._7009 import CylindricalPlanetGearAdvancedSystemDeflection
    from ._7010 import DatumAdvancedSystemDeflection
    from ._7011 import ExternalCADModelAdvancedSystemDeflection
    from ._7012 import FaceGearAdvancedSystemDeflection
    from ._7013 import FaceGearMeshAdvancedSystemDeflection
    from ._7014 import FaceGearSetAdvancedSystemDeflection
    from ._7015 import FEPartAdvancedSystemDeflection
    from ._7016 import FlexiblePinAssemblyAdvancedSystemDeflection
    from ._7017 import GearAdvancedSystemDeflection
    from ._7018 import GearMeshAdvancedSystemDeflection
    from ._7019 import GearSetAdvancedSystemDeflection
    from ._7020 import GuideDxfModelAdvancedSystemDeflection
    from ._7021 import HypoidGearAdvancedSystemDeflection
    from ._7022 import HypoidGearMeshAdvancedSystemDeflection
    from ._7023 import HypoidGearSetAdvancedSystemDeflection
    from ._7024 import InterMountableComponentConnectionAdvancedSystemDeflection
    from ._7025 import KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection
    from ._7026 import KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection
    from ._7027 import KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection
    from ._7028 import KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection
    from ._7029 import KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection
    from ._7030 import KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection
    from ._7031 import KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection
    from ._7032 import KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection
    from ._7033 import KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection
    from ._7034 import UseLtcaInAsdOption
    from ._7035 import MassDiscAdvancedSystemDeflection
    from ._7036 import MeasurementComponentAdvancedSystemDeflection
    from ._7037 import MountableComponentAdvancedSystemDeflection
    from ._7038 import OilSealAdvancedSystemDeflection
    from ._7039 import PartAdvancedSystemDeflection
    from ._7040 import PartToPartShearCouplingAdvancedSystemDeflection
    from ._7041 import PartToPartShearCouplingConnectionAdvancedSystemDeflection
    from ._7042 import PartToPartShearCouplingHalfAdvancedSystemDeflection
    from ._7043 import PlanetaryConnectionAdvancedSystemDeflection
    from ._7044 import PlanetaryGearSetAdvancedSystemDeflection
    from ._7045 import PlanetCarrierAdvancedSystemDeflection
    from ._7046 import PointLoadAdvancedSystemDeflection
    from ._7047 import PowerLoadAdvancedSystemDeflection
    from ._7048 import PulleyAdvancedSystemDeflection
    from ._7049 import RingPinsAdvancedSystemDeflection
    from ._7050 import RingPinsToDiscConnectionAdvancedSystemDeflection
    from ._7051 import RollingRingAdvancedSystemDeflection
    from ._7052 import RollingRingAssemblyAdvancedSystemDeflection
    from ._7053 import RollingRingConnectionAdvancedSystemDeflection
    from ._7054 import RootAssemblyAdvancedSystemDeflection
    from ._7055 import ShaftAdvancedSystemDeflection
    from ._7056 import ShaftHubConnectionAdvancedSystemDeflection
    from ._7057 import ShaftToMountableComponentConnectionAdvancedSystemDeflection
    from ._7058 import SpecialisedAssemblyAdvancedSystemDeflection
    from ._7059 import SpiralBevelGearAdvancedSystemDeflection
    from ._7060 import SpiralBevelGearMeshAdvancedSystemDeflection
    from ._7061 import SpiralBevelGearSetAdvancedSystemDeflection
    from ._7062 import SpringDamperAdvancedSystemDeflection
    from ._7063 import SpringDamperConnectionAdvancedSystemDeflection
    from ._7064 import SpringDamperHalfAdvancedSystemDeflection
    from ._7065 import StraightBevelDiffGearAdvancedSystemDeflection
    from ._7066 import StraightBevelDiffGearMeshAdvancedSystemDeflection
    from ._7067 import StraightBevelDiffGearSetAdvancedSystemDeflection
    from ._7068 import StraightBevelGearAdvancedSystemDeflection
    from ._7069 import StraightBevelGearMeshAdvancedSystemDeflection
    from ._7070 import StraightBevelGearSetAdvancedSystemDeflection
    from ._7071 import StraightBevelPlanetGearAdvancedSystemDeflection
    from ._7072 import StraightBevelSunGearAdvancedSystemDeflection
    from ._7073 import SynchroniserAdvancedSystemDeflection
    from ._7074 import SynchroniserHalfAdvancedSystemDeflection
    from ._7075 import SynchroniserPartAdvancedSystemDeflection
    from ._7076 import SynchroniserSleeveAdvancedSystemDeflection
    from ._7077 import TorqueConverterAdvancedSystemDeflection
    from ._7078 import TorqueConverterConnectionAdvancedSystemDeflection
    from ._7079 import TorqueConverterPumpAdvancedSystemDeflection
    from ._7080 import TorqueConverterTurbineAdvancedSystemDeflection
    from ._7081 import TransmissionErrorToOtherPowerLoad
    from ._7082 import UnbalancedMassAdvancedSystemDeflection
    from ._7083 import VirtualComponentAdvancedSystemDeflection
    from ._7084 import WormGearAdvancedSystemDeflection
    from ._7085 import WormGearMeshAdvancedSystemDeflection
    from ._7086 import WormGearSetAdvancedSystemDeflection
    from ._7087 import ZerolBevelGearAdvancedSystemDeflection
    from ._7088 import ZerolBevelGearMeshAdvancedSystemDeflection
    from ._7089 import ZerolBevelGearSetAdvancedSystemDeflection



'''_1022.py

ToothThicknessSpecificationBase
'''


from typing import List

from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor, conversion
from mastapy.gears.gear_designs.cylindrical import _971
from mastapy.utility.units_and_measurements.measurements import _1434, _1450
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_TOOTH_THICKNESS_SPECIFICATION_BASE = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'ToothThicknessSpecificationBase')


__docformat__ = 'restructuredtext en'
__all__ = ('ToothThicknessSpecificationBase',)


class ToothThicknessSpecificationBase(_0.APIBase):
    '''ToothThicknessSpecificationBase

    This is a mastapy class.
    '''

    TYPE = _TOOTH_THICKNESS_SPECIFICATION_BASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ToothThicknessSpecificationBase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def ball_diameter(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'BallDiameter' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.BallDiameter) if self.wrapped.BallDiameter else None

    @ball_diameter.setter
    def ball_diameter(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.BallDiameter = value

    @property
    def ball_diameter_at_tip_form_diameter(self) -> 'float':
        '''float: 'BallDiameterAtTipFormDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BallDiameterAtTipFormDiameter

    @property
    def ball_diameter_at_form_diameter(self) -> 'float':
        '''float: 'BallDiameterAtFormDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BallDiameterAtFormDiameter

    @property
    def number_of_teeth_for_chordal_span_test(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'NumberOfTeethForChordalSpanTest' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.NumberOfTeethForChordalSpanTest) if self.wrapped.NumberOfTeethForChordalSpanTest else None

    @number_of_teeth_for_chordal_span_test.setter
    def number_of_teeth_for_chordal_span_test(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0, is_overridden)
        self.wrapped.NumberOfTeethForChordalSpanTest = value

    @property
    def minimum_number_of_teeth_for_chordal_span_test(self) -> 'int':
        '''int: 'MinimumNumberOfTeethForChordalSpanTest' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumNumberOfTeethForChordalSpanTest

    @property
    def maximum_number_of_teeth_for_chordal_span_test(self) -> 'int':
        '''int: 'MaximumNumberOfTeethForChordalSpanTest' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumNumberOfTeethForChordalSpanTest

    @property
    def diameter_at_thickness_measurement(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'DiameterAtThicknessMeasurement' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.DiameterAtThicknessMeasurement) if self.wrapped.DiameterAtThicknessMeasurement else None

    @diameter_at_thickness_measurement.setter
    def diameter_at_thickness_measurement(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.DiameterAtThicknessMeasurement = value

    @property
    def normal_thickness(self) -> '_971.CylindricalGearToothThicknessSpecification[_1434.LengthShort]':
        '''CylindricalGearToothThicknessSpecification[LengthShort]: 'NormalThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1434.LengthShort](self.wrapped.NormalThickness) if self.wrapped.NormalThickness else None

    @property
    def normal_thickness_at_specified_diameter(self) -> '_971.CylindricalGearToothThicknessSpecification[_1434.LengthShort]':
        '''CylindricalGearToothThicknessSpecification[LengthShort]: 'NormalThicknessAtSpecifiedDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1434.LengthShort](self.wrapped.NormalThicknessAtSpecifiedDiameter) if self.wrapped.NormalThicknessAtSpecifiedDiameter else None

    @property
    def chordal_span(self) -> '_971.CylindricalGearToothThicknessSpecification[_1434.LengthShort]':
        '''CylindricalGearToothThicknessSpecification[LengthShort]: 'ChordalSpan' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1434.LengthShort](self.wrapped.ChordalSpan) if self.wrapped.ChordalSpan else None

    @property
    def over_balls(self) -> '_971.CylindricalGearToothThicknessSpecification[_1434.LengthShort]':
        '''CylindricalGearToothThicknessSpecification[LengthShort]: 'OverBalls' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1434.LengthShort](self.wrapped.OverBalls) if self.wrapped.OverBalls else None

    @property
    def transverse_thickness(self) -> '_971.CylindricalGearToothThicknessSpecification[_1434.LengthShort]':
        '''CylindricalGearToothThicknessSpecification[LengthShort]: 'TransverseThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1434.LengthShort](self.wrapped.TransverseThickness) if self.wrapped.TransverseThickness else None

    @property
    def transverse_thickness_at_specified_diameter(self) -> '_971.CylindricalGearToothThicknessSpecification[_1434.LengthShort]':
        '''CylindricalGearToothThicknessSpecification[LengthShort]: 'TransverseThicknessAtSpecifiedDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1434.LengthShort](self.wrapped.TransverseThicknessAtSpecifiedDiameter) if self.wrapped.TransverseThicknessAtSpecifiedDiameter else None

    @property
    def profile_shift_coefficient(self) -> '_971.CylindricalGearToothThicknessSpecification[_1450.Number]':
        '''CylindricalGearToothThicknessSpecification[Number]: 'ProfileShiftCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1450.Number](self.wrapped.ProfileShiftCoefficient) if self.wrapped.ProfileShiftCoefficient else None

    @property
    def profile_shift(self) -> '_971.CylindricalGearToothThicknessSpecification[_1434.LengthShort]':
        '''CylindricalGearToothThicknessSpecification[LengthShort]: 'ProfileShift' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1434.LengthShort](self.wrapped.ProfileShift) if self.wrapped.ProfileShift else None

    @property
    def tooth_thickness(self) -> 'List[_971.CylindricalGearToothThicknessSpecification[_1434.LengthShort]]':
        '''List[CylindricalGearToothThicknessSpecification[LengthShort]]: 'ToothThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ToothThickness, constructor.new(_971.CylindricalGearToothThicknessSpecification)[_1434.LengthShort])
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2944 import AbstractAssemblySteadyStateSynchronousResponseAtASpeed
    from ._2945 import AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed
    from ._2946 import AbstractShaftSteadyStateSynchronousResponseAtASpeed
    from ._2947 import AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2948 import AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2949 import AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2950 import AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._2951 import AssemblySteadyStateSynchronousResponseAtASpeed
    from ._2952 import BearingSteadyStateSynchronousResponseAtASpeed
    from ._2953 import BeltConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2954 import BeltDriveSteadyStateSynchronousResponseAtASpeed
    from ._2955 import BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2956 import BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2957 import BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed
    from ._2958 import BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._2959 import BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed
    from ._2960 import BevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2961 import BevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2962 import BevelGearSteadyStateSynchronousResponseAtASpeed
    from ._2963 import BoltedJointSteadyStateSynchronousResponseAtASpeed
    from ._2964 import BoltSteadyStateSynchronousResponseAtASpeed
    from ._2965 import ClutchConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2966 import ClutchHalfSteadyStateSynchronousResponseAtASpeed
    from ._2967 import ClutchSteadyStateSynchronousResponseAtASpeed
    from ._2968 import CoaxialConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2969 import ComponentSteadyStateSynchronousResponseAtASpeed
    from ._2970 import ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2971 import ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._2972 import ConceptCouplingSteadyStateSynchronousResponseAtASpeed
    from ._2973 import ConceptGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2974 import ConceptGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2975 import ConceptGearSteadyStateSynchronousResponseAtASpeed
    from ._2976 import ConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2977 import ConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2978 import ConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._2979 import ConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2980 import ConnectorSteadyStateSynchronousResponseAtASpeed
    from ._2981 import CouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2982 import CouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._2983 import CouplingSteadyStateSynchronousResponseAtASpeed
    from ._2984 import CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2985 import CVTPulleySteadyStateSynchronousResponseAtASpeed
    from ._2986 import CVTSteadyStateSynchronousResponseAtASpeed
    from ._2987 import CycloidalAssemblySteadyStateSynchronousResponseAtASpeed
    from ._2988 import CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2989 import CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2990 import CycloidalDiscSteadyStateSynchronousResponseAtASpeed
    from ._2991 import CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2992 import CylindricalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2993 import CylindricalGearSteadyStateSynchronousResponseAtASpeed
    from ._2994 import CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._2995 import DatumSteadyStateSynchronousResponseAtASpeed
    from ._2996 import ExternalCADModelSteadyStateSynchronousResponseAtASpeed
    from ._2997 import FaceGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2998 import FaceGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2999 import FaceGearSteadyStateSynchronousResponseAtASpeed
    from ._3000 import FEPartSteadyStateSynchronousResponseAtASpeed
    from ._3001 import FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3002 import GearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3003 import GearSetSteadyStateSynchronousResponseAtASpeed
    from ._3004 import GearSteadyStateSynchronousResponseAtASpeed
    from ._3005 import GuideDxfModelSteadyStateSynchronousResponseAtASpeed
    from ._3006 import HypoidGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3007 import HypoidGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3008 import HypoidGearSteadyStateSynchronousResponseAtASpeed
    from ._3009 import InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3010 import KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3011 import KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3012 import KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._3013 import KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3014 import KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3015 import KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed
    from ._3016 import KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3017 import KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3018 import KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3019 import MassDiscSteadyStateSynchronousResponseAtASpeed
    from ._3020 import MeasurementComponentSteadyStateSynchronousResponseAtASpeed
    from ._3021 import MountableComponentSteadyStateSynchronousResponseAtASpeed
    from ._3022 import OilSealSteadyStateSynchronousResponseAtASpeed
    from ._3023 import PartSteadyStateSynchronousResponseAtASpeed
    from ._3024 import PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3025 import PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._3026 import PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed
    from ._3027 import PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3028 import PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3029 import PlanetCarrierSteadyStateSynchronousResponseAtASpeed
    from ._3030 import PointLoadSteadyStateSynchronousResponseAtASpeed
    from ._3031 import PowerLoadSteadyStateSynchronousResponseAtASpeed
    from ._3032 import PulleySteadyStateSynchronousResponseAtASpeed
    from ._3033 import RingPinsSteadyStateSynchronousResponseAtASpeed
    from ._3034 import RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3035 import RollingRingAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3036 import RollingRingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3037 import RollingRingSteadyStateSynchronousResponseAtASpeed
    from ._3038 import RootAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3039 import ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3040 import ShaftSteadyStateSynchronousResponseAtASpeed
    from ._3041 import ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3042 import SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3043 import SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3044 import SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3045 import SpiralBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3046 import SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3047 import SpringDamperHalfSteadyStateSynchronousResponseAtASpeed
    from ._3048 import SpringDamperSteadyStateSynchronousResponseAtASpeed
    from ._3049 import SteadyStateSynchronousResponseAtASpeed
    from ._3050 import StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3051 import StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3052 import StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed
    from ._3053 import StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3054 import StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3055 import StraightBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3056 import StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._3057 import StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed
    from ._3058 import SynchroniserHalfSteadyStateSynchronousResponseAtASpeed
    from ._3059 import SynchroniserPartSteadyStateSynchronousResponseAtASpeed
    from ._3060 import SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed
    from ._3061 import SynchroniserSteadyStateSynchronousResponseAtASpeed
    from ._3062 import TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3063 import TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed
    from ._3064 import TorqueConverterSteadyStateSynchronousResponseAtASpeed
    from ._3065 import TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed
    from ._3066 import UnbalancedMassSteadyStateSynchronousResponseAtASpeed
    from ._3067 import VirtualComponentSteadyStateSynchronousResponseAtASpeed
    from ._3068 import WormGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3069 import WormGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3070 import WormGearSteadyStateSynchronousResponseAtASpeed
    from ._3071 import ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3072 import ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3073 import ZerolBevelGearSteadyStateSynchronousResponseAtASpeed



'''_488.py

AGMA2101MeshSingleFlankRating
'''


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.gears.gear_designs.cylindrical import _964, _1008
from mastapy.materials import _225
from mastapy.gears.rating.cylindrical.agma import _487
from mastapy.gears.rating.cylindrical import _430
from mastapy._internal.python_net import python_net_import

_AGMA2101_MESH_SINGLE_FLANK_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical.AGMA', 'AGMA2101MeshSingleFlankRating')


__docformat__ = 'restructuredtext en'
__all__ = ('AGMA2101MeshSingleFlankRating',)


class AGMA2101MeshSingleFlankRating(_430.CylindricalMeshSingleFlankRating):
    '''AGMA2101MeshSingleFlankRating

    This is a mastapy class.
    '''

    TYPE = _AGMA2101_MESH_SINGLE_FLANK_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'AGMA2101MeshSingleFlankRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rating_standard_name(self) -> 'str':
        '''str: 'RatingStandardName' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RatingStandardName

    @property
    def pinion_offset_from_bearing(self) -> 'float':
        '''float: 'PinionOffsetFromBearing' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionOffsetFromBearing

    @property
    def bearing_span(self) -> 'float':
        '''float: 'BearingSpan' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BearingSpan

    @property
    def improved_gearing(self) -> 'bool':
        '''bool: 'ImprovedGearing' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ImprovedGearing

    @property
    def profile_modification(self) -> '_964.CylindricalGearProfileModifications':
        '''CylindricalGearProfileModifications: 'ProfileModification' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.ProfileModification)
        return constructor.new(_964.CylindricalGearProfileModifications)(value) if value else None

    @property
    def gearing_type(self) -> '_225.GearingTypes':
        '''GearingTypes: 'GearingType' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.GearingType)
        return constructor.new(_225.GearingTypes)(value) if value else None

    @property
    def scuffing_temperature_method(self) -> '_1008.ScuffingTemperatureMethodsAGMA':
        '''ScuffingTemperatureMethodsAGMA: 'ScuffingTemperatureMethod' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.ScuffingTemperatureMethod)
        return constructor.new(_1008.ScuffingTemperatureMethodsAGMA)(value) if value else None

    @property
    def overload_factor(self) -> 'float':
        '''float: 'OverloadFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OverloadFactor

    @property
    def surface_condition_factor(self) -> 'float':
        '''float: 'SurfaceConditionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SurfaceConditionFactor

    @property
    def parameter_for_calculating_tooth_temperature(self) -> 'float':
        '''float: 'ParameterForCalculatingToothTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ParameterForCalculatingToothTemperature

    @property
    def filter_cutoff_wave_length(self) -> 'float':
        '''float: 'FilterCutoffWaveLength' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FilterCutoffWaveLength

    @property
    def transverse_metric_module(self) -> 'float':
        '''float: 'TransverseMetricModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransverseMetricModule

    @property
    def size_factor_bending(self) -> 'float':
        '''float: 'SizeFactorBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SizeFactorBending

    @property
    def temperature_factor(self) -> 'float':
        '''float: 'TemperatureFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TemperatureFactor

    @property
    def load_distribution_factor(self) -> 'float':
        '''float: 'LoadDistributionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadDistributionFactor

    @property
    def transverse_load_distribution_factor(self) -> 'float':
        '''float: 'TransverseLoadDistributionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransverseLoadDistributionFactor

    @property
    def load_distribution_factor_source(self) -> 'str':
        '''str: 'LoadDistributionFactorSource' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadDistributionFactorSource

    @property
    def transmission_accuracy_number(self) -> 'float':
        '''float: 'TransmissionAccuracyNumber' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransmissionAccuracyNumber

    @property
    def contact_load_factor(self) -> 'float':
        '''float: 'ContactLoadFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ContactLoadFactor

    @property
    def operating_centre_distance(self) -> 'float':
        '''float: 'OperatingCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OperatingCentreDistance

    @property
    def sixth_distance_along_line_of_action(self) -> 'float':
        '''float: 'SixthDistanceAlongLineOfAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SixthDistanceAlongLineOfAction

    @property
    def first_distance_along_line_of_action(self) -> 'float':
        '''float: 'FirstDistanceAlongLineOfAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FirstDistanceAlongLineOfAction

    @property
    def third_distance_along_line_of_action(self) -> 'float':
        '''float: 'ThirdDistanceAlongLineOfAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ThirdDistanceAlongLineOfAction

    @property
    def fourth_distance_along_line_of_action(self) -> 'float':
        '''float: 'FourthDistanceAlongLineOfAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FourthDistanceAlongLineOfAction

    @property
    def fifth_distance_along_line_of_action(self) -> 'float':
        '''float: 'FifthDistanceAlongLineOfAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FifthDistanceAlongLineOfAction

    @property
    def second_distance_along_line_of_action(self) -> 'float':
        '''float: 'SecondDistanceAlongLineOfAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SecondDistanceAlongLineOfAction

    @property
    def active_length_of_line_of_contact(self) -> 'float':
        '''float: 'ActiveLengthOfLineOfContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ActiveLengthOfLineOfContact

    @property
    def minimum_contact_length(self) -> 'float':
        '''float: 'MinimumContactLength' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumContactLength

    @property
    def minimum_length_of_contact_lines_per_unit_module(self) -> 'float':
        '''float: 'MinimumLengthOfContactLinesPerUnitModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumLengthOfContactLinesPerUnitModule

    @property
    def load_sharing_ratio(self) -> 'float':
        '''float: 'LoadSharingRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadSharingRatio

    @property
    def helical_overlap_factor(self) -> 'float':
        '''float: 'HelicalOverlapFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HelicalOverlapFactor

    @property
    def geometry_factor_i(self) -> 'float':
        '''float: 'GeometryFactorI' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.GeometryFactorI

    @property
    def elastic_coefficient(self) -> 'float':
        '''float: 'ElasticCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElasticCoefficient

    @property
    def face_load_distribution_factor(self) -> 'float':
        '''float: 'FaceLoadDistributionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FaceLoadDistributionFactor

    @property
    def lead_correction_factor(self) -> 'float':
        '''float: 'LeadCorrectionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LeadCorrectionFactor

    @property
    def pinion_proportion_factor(self) -> 'float':
        '''float: 'PinionProportionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionProportionFactor

    @property
    def pinion_proportion_modifier(self) -> 'float':
        '''float: 'PinionProportionModifier' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionProportionModifier

    @property
    def mesh_alignment_factor(self) -> 'float':
        '''float: 'MeshAlignmentFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeshAlignmentFactor

    @property
    def mesh_alignment_correction_factor(self) -> 'float':
        '''float: 'MeshAlignmentCorrectionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeshAlignmentCorrectionFactor

    @property
    def average_roughness_ra(self) -> 'float':
        '''float: 'AverageRoughnessRa' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AverageRoughnessRa

    @property
    def surface_roughness_constant(self) -> 'float':
        '''float: 'SurfaceRoughnessConstant' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SurfaceRoughnessConstant

    @property
    def mean_coefficient_of_friction_calculated_constant_flash_temperature_method(self) -> 'float':
        '''float: 'MeanCoefficientOfFrictionCalculatedConstantFlashTemperatureMethod' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanCoefficientOfFrictionCalculatedConstantFlashTemperatureMethod

    @property
    def composite_surface_roughness_at_fc(self) -> 'float':
        '''float: 'CompositeSurfaceRoughnessAtFC' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CompositeSurfaceRoughnessAtFC

    @property
    def combined_derating_factor(self) -> 'float':
        '''float: 'CombinedDeratingFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CombinedDeratingFactor

    @property
    def actual_tangential_load(self) -> 'float':
        '''float: 'ActualTangentialLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ActualTangentialLoad

    @property
    def normal_operating_load(self) -> 'float':
        '''float: 'NormalOperatingLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalOperatingLoad

    @property
    def normal_unit_load(self) -> 'float':
        '''float: 'NormalUnitLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalUnitLoad

    @property
    def sliding_velocity_at_start_of_active_profile(self) -> 'float':
        '''float: 'SlidingVelocityAtStartOfActiveProfile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SlidingVelocityAtStartOfActiveProfile

    @property
    def sliding_velocity_at_end_of_active_profile(self) -> 'float':
        '''float: 'SlidingVelocityAtEndOfActiveProfile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SlidingVelocityAtEndOfActiveProfile

    @property
    def sliding_velocity_at_pitch_point(self) -> 'float':
        '''float: 'SlidingVelocityAtPitchPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SlidingVelocityAtPitchPoint

    @property
    def entraining_velocity_at_start_of_active_profile(self) -> 'float':
        '''float: 'EntrainingVelocityAtStartOfActiveProfile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EntrainingVelocityAtStartOfActiveProfile

    @property
    def entraining_velocity_at_end_of_active_profile(self) -> 'float':
        '''float: 'EntrainingVelocityAtEndOfActiveProfile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EntrainingVelocityAtEndOfActiveProfile

    @property
    def entraining_velocity_at_pitch_point(self) -> 'float':
        '''float: 'EntrainingVelocityAtPitchPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EntrainingVelocityAtPitchPoint

    @property
    def materials_parameter(self) -> 'float':
        '''float: 'MaterialsParameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaterialsParameter

    @property
    def pressure_viscosity_coefficient(self) -> 'float':
        '''float: 'PressureViscosityCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PressureViscosityCoefficient

    @property
    def maximum_contact_temperature(self) -> 'float':
        '''float: 'MaximumContactTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumContactTemperature

    @property
    def maximum_flash_temperature(self) -> 'float':
        '''float: 'MaximumFlashTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumFlashTemperature

    @property
    def tooth_temperature(self) -> 'float':
        '''float: 'ToothTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothTemperature

    @property
    def scuffing_temperature(self) -> 'float':
        '''float: 'ScuffingTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ScuffingTemperature

    @property
    def sump_temperature(self) -> 'float':
        '''float: 'SumpTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SumpTemperature

    @property
    def minimum_film_thickness(self) -> 'float':
        '''float: 'MinimumFilmThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumFilmThickness

    @property
    def minimum_specific_film_thickness(self) -> 'float':
        '''float: 'MinimumSpecificFilmThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumSpecificFilmThickness

    @property
    def probability_of_scuffing(self) -> 'float':
        '''float: 'ProbabilityOfScuffing' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ProbabilityOfScuffing

    @property
    def probability_of_wear(self) -> 'float':
        '''float: 'ProbabilityOfWear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ProbabilityOfWear

    @property
    def gear_single_flank_ratings(self) -> 'List[_487.AGMA2101GearSingleFlankRating]':
        '''List[AGMA2101GearSingleFlankRating]: 'GearSingleFlankRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearSingleFlankRatings, constructor.new(_487.AGMA2101GearSingleFlankRating))
        return value

    @property
    def agma_cylindrical_gear_single_flank_ratings(self) -> 'List[_487.AGMA2101GearSingleFlankRating]':
        '''List[AGMA2101GearSingleFlankRating]: 'AGMACylindricalGearSingleFlankRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AGMACylindricalGearSingleFlankRatings, constructor.new(_487.AGMA2101GearSingleFlankRating))
        return value



'''_6575.py

GearMeshTEOrderType
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_GEAR_MESH_TE_ORDER_TYPE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'GearMeshTEOrderType')


__docformat__ = 'restructuredtext en'
__all__ = ('GearMeshTEOrderType',)


class GearMeshTEOrderType(Enum):
    '''GearMeshTEOrderType

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _GEAR_MESH_TE_ORDER_TYPE

    __hash__ = None

    ORDERS_WITH_RESPECT_TO_PRIMARY_MESH_ORDER = 0
    ORDERS_WITH_RESPECT_TO_REFERENCE_SHAFT = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


GearMeshTEOrderType.__setattr__ = __enum_setattr
GearMeshTEOrderType.__delattr__ = __enum_delattr



'''_6553.py

ElectricMachineDetailDatabase
'''


from mastapy.utility.databases import _1576
from mastapy.system_model.analyses_and_results.static_loads import _6552
from mastapy._internal.python_net import python_net_import

_ELECTRIC_MACHINE_DETAIL_DATABASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'ElectricMachineDetailDatabase')


__docformat__ = 'restructuredtext en'
__all__ = ('ElectricMachineDetailDatabase',)


class ElectricMachineDetailDatabase(_1576.NamedDatabase['_6552.ElectricMachineDetail']):
    '''ElectricMachineDetailDatabase

    This is a mastapy class.
    '''

    TYPE = _ELECTRIC_MACHINE_DETAIL_DATABASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElectricMachineDetailDatabase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._5069 import AbstractAssemblyMultibodyDynamicsAnalysis
    from ._5070 import AbstractShaftMultibodyDynamicsAnalysis
    from ._5071 import AbstractShaftOrHousingMultibodyDynamicsAnalysis
    from ._5072 import AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis
    from ._5073 import AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis
    from ._5074 import AGMAGleasonConicalGearMultibodyDynamicsAnalysis
    from ._5075 import AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis
    from ._5076 import AnalysisTypes
    from ._5077 import AssemblyMultibodyDynamicsAnalysis
    from ._5078 import BearingMultibodyDynamicsAnalysis
    from ._5079 import BearingStiffnessModel
    from ._5080 import BeltConnectionMultibodyDynamicsAnalysis
    from ._5081 import BeltDriveMultibodyDynamicsAnalysis
    from ._5082 import BevelDifferentialGearMeshMultibodyDynamicsAnalysis
    from ._5083 import BevelDifferentialGearMultibodyDynamicsAnalysis
    from ._5084 import BevelDifferentialGearSetMultibodyDynamicsAnalysis
    from ._5085 import BevelDifferentialPlanetGearMultibodyDynamicsAnalysis
    from ._5086 import BevelDifferentialSunGearMultibodyDynamicsAnalysis
    from ._5087 import BevelGearMeshMultibodyDynamicsAnalysis
    from ._5088 import BevelGearMultibodyDynamicsAnalysis
    from ._5089 import BevelGearSetMultibodyDynamicsAnalysis
    from ._5090 import BoltedJointMultibodyDynamicsAnalysis
    from ._5091 import BoltMultibodyDynamicsAnalysis
    from ._5092 import ClutchConnectionMultibodyDynamicsAnalysis
    from ._5093 import ClutchHalfMultibodyDynamicsAnalysis
    from ._5094 import ClutchMultibodyDynamicsAnalysis
    from ._5095 import ClutchSpringType
    from ._5096 import CoaxialConnectionMultibodyDynamicsAnalysis
    from ._5097 import ComponentMultibodyDynamicsAnalysis
    from ._5098 import ConceptCouplingConnectionMultibodyDynamicsAnalysis
    from ._5099 import ConceptCouplingHalfMultibodyDynamicsAnalysis
    from ._5100 import ConceptCouplingMultibodyDynamicsAnalysis
    from ._5101 import ConceptGearMeshMultibodyDynamicsAnalysis
    from ._5102 import ConceptGearMultibodyDynamicsAnalysis
    from ._5103 import ConceptGearSetMultibodyDynamicsAnalysis
    from ._5104 import ConicalGearMeshMultibodyDynamicsAnalysis
    from ._5105 import ConicalGearMultibodyDynamicsAnalysis
    from ._5106 import ConicalGearSetMultibodyDynamicsAnalysis
    from ._5107 import ConnectionMultibodyDynamicsAnalysis
    from ._5108 import ConnectorMultibodyDynamicsAnalysis
    from ._5109 import CouplingConnectionMultibodyDynamicsAnalysis
    from ._5110 import CouplingHalfMultibodyDynamicsAnalysis
    from ._5111 import CouplingMultibodyDynamicsAnalysis
    from ._5112 import CVTBeltConnectionMultibodyDynamicsAnalysis
    from ._5113 import CVTMultibodyDynamicsAnalysis
    from ._5114 import CVTPulleyMultibodyDynamicsAnalysis
    from ._5115 import CycloidalAssemblyMultibodyDynamicsAnalysis
    from ._5116 import CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis
    from ._5117 import CycloidalDiscMultibodyDynamicsAnalysis
    from ._5118 import CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis
    from ._5119 import CylindricalGearMeshMultibodyDynamicsAnalysis
    from ._5120 import CylindricalGearMultibodyDynamicsAnalysis
    from ._5121 import CylindricalGearSetMultibodyDynamicsAnalysis
    from ._5122 import CylindricalPlanetGearMultibodyDynamicsAnalysis
    from ._5123 import DatumMultibodyDynamicsAnalysis
    from ._5124 import ExternalCADModelMultibodyDynamicsAnalysis
    from ._5125 import FaceGearMeshMultibodyDynamicsAnalysis
    from ._5126 import FaceGearMultibodyDynamicsAnalysis
    from ._5127 import FaceGearSetMultibodyDynamicsAnalysis
    from ._5128 import FEPartMultibodyDynamicsAnalysis
    from ._5129 import FlexiblePinAssemblyMultibodyDynamicsAnalysis
    from ._5130 import GearMeshMultibodyDynamicsAnalysis
    from ._5131 import GearMeshStiffnessModel
    from ._5132 import GearMultibodyDynamicsAnalysis
    from ._5133 import GearSetMultibodyDynamicsAnalysis
    from ._5134 import GuideDxfModelMultibodyDynamicsAnalysis
    from ._5135 import HypoidGearMeshMultibodyDynamicsAnalysis
    from ._5136 import HypoidGearMultibodyDynamicsAnalysis
    from ._5137 import HypoidGearSetMultibodyDynamicsAnalysis
    from ._5138 import InertiaAdjustedLoadCasePeriodMethod
    from ._5139 import InertiaAdjustedLoadCaseResultsToCreate
    from ._5140 import InputSignalFilterLevel
    from ._5141 import InputVelocityForRunUpProcessingType
    from ._5142 import InterMountableComponentConnectionMultibodyDynamicsAnalysis
    from ._5143 import KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis
    from ._5144 import KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis
    from ._5145 import KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis
    from ._5146 import KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis
    from ._5147 import KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis
    from ._5148 import KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis
    from ._5149 import KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis
    from ._5150 import KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis
    from ._5151 import KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis
    from ._5152 import MassDiscMultibodyDynamicsAnalysis
    from ._5153 import MBDAnalysisDrawStyle
    from ._5154 import MBDAnalysisOptions
    from ._5155 import MBDRunUpAnalysisOptions
    from ._5156 import MeasurementComponentMultibodyDynamicsAnalysis
    from ._5157 import MountableComponentMultibodyDynamicsAnalysis
    from ._2346 import MultibodyDynamicsAnalysis
    from ._5158 import OilSealMultibodyDynamicsAnalysis
    from ._5159 import PartMultibodyDynamicsAnalysis
    from ._5160 import PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis
    from ._5161 import PartToPartShearCouplingHalfMultibodyDynamicsAnalysis
    from ._5162 import PartToPartShearCouplingMultibodyDynamicsAnalysis
    from ._5163 import PlanetaryConnectionMultibodyDynamicsAnalysis
    from ._5164 import PlanetaryGearSetMultibodyDynamicsAnalysis
    from ._5165 import PlanetCarrierMultibodyDynamicsAnalysis
    from ._5166 import PointLoadMultibodyDynamicsAnalysis
    from ._5167 import PowerLoadMultibodyDynamicsAnalysis
    from ._5168 import PulleyMultibodyDynamicsAnalysis
    from ._5169 import RingPinsMultibodyDynamicsAnalysis
    from ._5170 import RingPinsToDiscConnectionMultibodyDynamicsAnalysis
    from ._5171 import RollingRingAssemblyMultibodyDynamicsAnalysis
    from ._5172 import RollingRingConnectionMultibodyDynamicsAnalysis
    from ._5173 import RollingRingMultibodyDynamicsAnalysis
    from ._5174 import RootAssemblyMultibodyDynamicsAnalysis
    from ._5175 import RunUpDrivingMode
    from ._5176 import ShaftAndHousingFlexibilityOption
    from ._5177 import ShaftHubConnectionMultibodyDynamicsAnalysis
    from ._5178 import ShaftMultibodyDynamicsAnalysis
    from ._5179 import ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis
    from ._5180 import ShapeOfInitialAccelerationPeriodForRunUp
    from ._5181 import SpecialisedAssemblyMultibodyDynamicsAnalysis
    from ._5182 import SpiralBevelGearMeshMultibodyDynamicsAnalysis
    from ._5183 import SpiralBevelGearMultibodyDynamicsAnalysis
    from ._5184 import SpiralBevelGearSetMultibodyDynamicsAnalysis
    from ._5185 import SpringDamperConnectionMultibodyDynamicsAnalysis
    from ._5186 import SpringDamperHalfMultibodyDynamicsAnalysis
    from ._5187 import SpringDamperMultibodyDynamicsAnalysis
    from ._5188 import StraightBevelDiffGearMeshMultibodyDynamicsAnalysis
    from ._5189 import StraightBevelDiffGearMultibodyDynamicsAnalysis
    from ._5190 import StraightBevelDiffGearSetMultibodyDynamicsAnalysis
    from ._5191 import StraightBevelGearMeshMultibodyDynamicsAnalysis
    from ._5192 import StraightBevelGearMultibodyDynamicsAnalysis
    from ._5193 import StraightBevelGearSetMultibodyDynamicsAnalysis
    from ._5194 import StraightBevelPlanetGearMultibodyDynamicsAnalysis
    from ._5195 import StraightBevelSunGearMultibodyDynamicsAnalysis
    from ._5196 import SynchroniserHalfMultibodyDynamicsAnalysis
    from ._5197 import SynchroniserMultibodyDynamicsAnalysis
    from ._5198 import SynchroniserPartMultibodyDynamicsAnalysis
    from ._5199 import SynchroniserSleeveMultibodyDynamicsAnalysis
    from ._5200 import TorqueConverterConnectionMultibodyDynamicsAnalysis
    from ._5201 import TorqueConverterLockupRule
    from ._5202 import TorqueConverterMultibodyDynamicsAnalysis
    from ._5203 import TorqueConverterPumpMultibodyDynamicsAnalysis
    from ._5204 import TorqueConverterStatus
    from ._5205 import TorqueConverterTurbineMultibodyDynamicsAnalysis
    from ._5206 import UnbalancedMassMultibodyDynamicsAnalysis
    from ._5207 import VirtualComponentMultibodyDynamicsAnalysis
    from ._5208 import WheelSlipType
    from ._5209 import WormGearMeshMultibodyDynamicsAnalysis
    from ._5210 import WormGearMultibodyDynamicsAnalysis
    from ._5211 import WormGearSetMultibodyDynamicsAnalysis
    from ._5212 import ZerolBevelGearMeshMultibodyDynamicsAnalysis
    from ._5213 import ZerolBevelGearMultibodyDynamicsAnalysis
    from ._5214 import ZerolBevelGearSetMultibodyDynamicsAnalysis



'''_4315.py

CycloidalDiscModalAnalysisAtAStiffness
'''


from mastapy.system_model.part_model.cycloidal import _2276
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6540
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import _4271
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_DISC_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness', 'CycloidalDiscModalAnalysisAtAStiffness')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalDiscModalAnalysisAtAStiffness',)


class CycloidalDiscModalAnalysisAtAStiffness(_4271.AbstractShaftModalAnalysisAtAStiffness):
    '''CycloidalDiscModalAnalysisAtAStiffness

    This is a mastapy class.
    '''

    TYPE = _CYCLOIDAL_DISC_MODAL_ANALYSIS_AT_A_STIFFNESS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalDiscModalAnalysisAtAStiffness.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2276.CycloidalDisc':
        '''CycloidalDisc: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2276.CycloidalDisc)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6540.CycloidalDiscLoadCase':
        '''CycloidalDiscLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6540.CycloidalDiscLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_1617.py

OuterRingMounting
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_OUTER_RING_MOUNTING = python_net_import('SMT.MastaAPI.Bearings', 'OuterRingMounting')


__docformat__ = 'restructuredtext en'
__all__ = ('OuterRingMounting',)


class OuterRingMounting(Enum):
    '''OuterRingMounting

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _OUTER_RING_MOUNTING

    __hash__ = None

    STANDARD = 0
    SPHERICAL = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


OuterRingMounting.__setattr__ = __enum_setattr
OuterRingMounting.__delattr__ = __enum_delattr



'''_828.py

ConicalMeshLoadCase
'''


from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.gears.gear_designs.conical import _1079, _1089
from mastapy.gears.load_case import _816
from mastapy._internal.python_net import python_net_import

_CONICAL_MESH_LOAD_CASE = python_net_import('SMT.MastaAPI.Gears.LoadCase.Conical', 'ConicalMeshLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalMeshLoadCase',)


class ConicalMeshLoadCase(_816.MeshLoadCase):
    '''ConicalMeshLoadCase

    This is a mastapy class.
    '''

    TYPE = _CONICAL_MESH_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalMeshLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def use_user_specified_misalignments_in_tca(self) -> 'bool':
        '''bool: 'UseUserSpecifiedMisalignmentsInTCA' is the original name of this property.'''

        return self.wrapped.UseUserSpecifiedMisalignmentsInTCA

    @use_user_specified_misalignments_in_tca.setter
    def use_user_specified_misalignments_in_tca(self, value: 'bool'):
        self.wrapped.UseUserSpecifiedMisalignmentsInTCA = bool(value) if value else False

    @property
    def active_flank(self) -> '_1079.ActiveConicalFlank':
        '''ActiveConicalFlank: 'ActiveFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.ActiveFlank)
        return constructor.new(_1079.ActiveConicalFlank)(value) if value else None

    @property
    def misalignments_total(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MisalignmentsTotal' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MisalignmentsTotal) if self.wrapped.MisalignmentsTotal else None

    @property
    def misalignments_pinion(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MisalignmentsPinion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MisalignmentsPinion) if self.wrapped.MisalignmentsPinion else None

    @property
    def misalignments_wheel(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MisalignmentsWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MisalignmentsWheel) if self.wrapped.MisalignmentsWheel else None

    @property
    def misalignments_with_respect_to_cross_point_using_reference_fe_substructure_node_total(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodeTotal' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodeTotal) if self.wrapped.MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodeTotal else None

    @property
    def misalignments_with_respect_to_cross_point_using_reference_fe_substructure_node_pinion(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodePinion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodePinion) if self.wrapped.MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodePinion else None

    @property
    def misalignments_with_respect_to_cross_point_using_reference_fe_substructure_node_wheel(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodeWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodeWheel) if self.wrapped.MisalignmentsWithRespectToCrossPointUsingReferenceFESubstructureNodeWheel else None

    @property
    def mesh_node_misalignments_total(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MeshNodeMisalignmentsTotal' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MeshNodeMisalignmentsTotal) if self.wrapped.MeshNodeMisalignmentsTotal else None

    @property
    def mesh_node_misalignments_pinion(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MeshNodeMisalignmentsPinion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MeshNodeMisalignmentsPinion) if self.wrapped.MeshNodeMisalignmentsPinion else None

    @property
    def mesh_node_misalignments_wheel(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'MeshNodeMisalignmentsWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.MeshNodeMisalignmentsWheel) if self.wrapped.MeshNodeMisalignmentsWheel else None

    @property
    def user_specified_misalignments(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'UserSpecifiedMisalignments' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.UserSpecifiedMisalignments) if self.wrapped.UserSpecifiedMisalignments else None



'''_6352.py

WormGearSetCriticalSpeedAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2259
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6670
from mastapy.system_model.analyses_and_results.critical_speed_analyses import _6350, _6351, _6287
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_SET_CRITICAL_SPEED_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.CriticalSpeedAnalyses', 'WormGearSetCriticalSpeedAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearSetCriticalSpeedAnalysis',)


class WormGearSetCriticalSpeedAnalysis(_6287.GearSetCriticalSpeedAnalysis):
    '''WormGearSetCriticalSpeedAnalysis

    This is a mastapy class.
    '''

    TYPE = _WORM_GEAR_SET_CRITICAL_SPEED_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGearSetCriticalSpeedAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2259.WormGearSet':
        '''WormGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2259.WormGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6670.WormGearSetLoadCase':
        '''WormGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6670.WormGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def worm_gears_critical_speed_analysis(self) -> 'List[_6350.WormGearCriticalSpeedAnalysis]':
        '''List[WormGearCriticalSpeedAnalysis]: 'WormGearsCriticalSpeedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormGearsCriticalSpeedAnalysis, constructor.new(_6350.WormGearCriticalSpeedAnalysis))
        return value

    @property
    def worm_meshes_critical_speed_analysis(self) -> 'List[_6351.WormGearMeshCriticalSpeedAnalysis]':
        '''List[WormGearMeshCriticalSpeedAnalysis]: 'WormMeshesCriticalSpeedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormMeshesCriticalSpeedAnalysis, constructor.new(_6351.WormGearMeshCriticalSpeedAnalysis))
        return value



'''_3148.py

KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponseAtASpeed
'''


from typing import List

from mastapy.system_model.part_model.gears import _2248
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import _3146, _3147, _3142
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _3017
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed.Compound', 'KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponseAtASpeed',)


class KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponseAtASpeed(_3142.KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponseAtASpeed):
    '''KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2248.KlingelnbergCycloPalloidSpiralBevelGearSet':
        '''KlingelnbergCycloPalloidSpiralBevelGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2248.KlingelnbergCycloPalloidSpiralBevelGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2248.KlingelnbergCycloPalloidSpiralBevelGearSet':
        '''KlingelnbergCycloPalloidSpiralBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2248.KlingelnbergCycloPalloidSpiralBevelGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gears_compound_steady_state_synchronous_response_at_a_speed(self) -> 'List[_3146.KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponseAtASpeed]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponseAtASpeed]: 'KlingelnbergCycloPalloidSpiralBevelGearsCompoundSteadyStateSynchronousResponseAtASpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearsCompoundSteadyStateSynchronousResponseAtASpeed, constructor.new(_3146.KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_meshes_compound_steady_state_synchronous_response_at_a_speed(self) -> 'List[_3147.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponseAtASpeed]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponseAtASpeed]: 'KlingelnbergCycloPalloidSpiralBevelMeshesCompoundSteadyStateSynchronousResponseAtASpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelMeshesCompoundSteadyStateSynchronousResponseAtASpeed, constructor.new(_3147.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_3017.KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_3017.KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_3017.KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_3017.KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed))
        return value



'''_1144.py

GearDesignAnalysis
'''


from mastapy.gears.analysis import _1141
from mastapy._internal.python_net import python_net_import

_GEAR_DESIGN_ANALYSIS = python_net_import('SMT.MastaAPI.Gears.Analysis', 'GearDesignAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('GearDesignAnalysis',)


class GearDesignAnalysis(_1141.AbstractGearAnalysis):
    '''GearDesignAnalysis

    This is a mastapy class.
    '''

    TYPE = _GEAR_DESIGN_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearDesignAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1067.py

CylindricalAccuracyGrader
'''


from mastapy._internal import constructor
from mastapy.gears.gear_designs.cylindrical.accuracy_and_tolerances import _1069, _1065, _1074
from mastapy._internal.cast_exception import CastException
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_ACCURACY_GRADER = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical.AccuracyAndTolerances', 'CylindricalAccuracyGrader')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalAccuracyGrader',)


class CylindricalAccuracyGrader(_0.APIBase):
    '''CylindricalAccuracyGrader

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_ACCURACY_GRADER

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalAccuracyGrader.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def single_pitch_deviation(self) -> 'float':
        '''float: 'SinglePitchDeviation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SinglePitchDeviation

    @property
    def total_radial_composite_deviation(self) -> 'float':
        '''float: 'TotalRadialCompositeDeviation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalRadialCompositeDeviation

    @property
    def toothto_tooth_radial_composite_deviation(self) -> 'float':
        '''float: 'ToothtoToothRadialCompositeDeviation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothtoToothRadialCompositeDeviation

    @property
    def runout(self) -> 'float':
        '''float: 'Runout' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Runout

    @property
    def tolerance_standard(self) -> 'str':
        '''str: 'ToleranceStandard' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToleranceStandard

    @property
    def accuracy_grades(self) -> '_1069.CylindricalAccuracyGrades':
        '''CylindricalAccuracyGrades: 'AccuracyGrades' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1069.CylindricalAccuracyGrades.TYPE not in self.wrapped.AccuracyGrades.__class__.__mro__:
            raise CastException('Failed to cast accuracy_grades to CylindricalAccuracyGrades. Expected: {}.'.format(self.wrapped.AccuracyGrades.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AccuracyGrades.__class__)(self.wrapped.AccuracyGrades) if self.wrapped.AccuracyGrades else None

    @property
    def accuracy_grades_of_type_agma20151_accuracy_grades(self) -> '_1065.AGMA20151AccuracyGrades':
        '''AGMA20151AccuracyGrades: 'AccuracyGrades' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1065.AGMA20151AccuracyGrades.TYPE not in self.wrapped.AccuracyGrades.__class__.__mro__:
            raise CastException('Failed to cast accuracy_grades to AGMA20151AccuracyGrades. Expected: {}.'.format(self.wrapped.AccuracyGrades.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AccuracyGrades.__class__)(self.wrapped.AccuracyGrades) if self.wrapped.AccuracyGrades else None

    @property
    def accuracy_grades_of_type_iso1328_accuracy_grades(self) -> '_1074.ISO1328AccuracyGrades':
        '''ISO1328AccuracyGrades: 'AccuracyGrades' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1074.ISO1328AccuracyGrades.TYPE not in self.wrapped.AccuracyGrades.__class__.__mro__:
            raise CastException('Failed to cast accuracy_grades to ISO1328AccuracyGrades. Expected: {}.'.format(self.wrapped.AccuracyGrades.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AccuracyGrades.__class__)(self.wrapped.AccuracyGrades) if self.wrapped.AccuracyGrades else None



'''_2084.py

ElementFaceGroupWithSelection
'''


from mastapy.system_model.fe import _2086
from mastapy.nodal_analysis.component_mode_synthesis import _197
from mastapy.fe_tools.vis_tools_global import _1159
from mastapy._internal.python_net import python_net_import

_ELEMENT_FACE_GROUP_WITH_SELECTION = python_net_import('SMT.MastaAPI.SystemModel.FE', 'ElementFaceGroupWithSelection')


__docformat__ = 'restructuredtext en'
__all__ = ('ElementFaceGroupWithSelection',)


class ElementFaceGroupWithSelection(_2086.FEEntityGroupWithSelection['_197.CMSElementFaceGroup', '_1159.ElementFace']):
    '''ElementFaceGroupWithSelection

    This is a mastapy class.
    '''

    TYPE = _ELEMENT_FACE_GROUP_WITH_SELECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElementFaceGroupWithSelection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_364.py

StraightBevelGearMeshRating
'''


from typing import List

from mastapy.gears.gear_designs.straight_bevel import _904
from mastapy._internal import constructor, conversion
from mastapy.gears.rating.straight_bevel import _365
from mastapy.gears.rating.bevel import _506
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_GEAR_MESH_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.StraightBevel', 'StraightBevelGearMeshRating')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelGearMeshRating',)


class StraightBevelGearMeshRating(_506.BevelGearMeshRating):
    '''StraightBevelGearMeshRating

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_GEAR_MESH_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelGearMeshRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def straight_bevel_gear_mesh(self) -> '_904.StraightBevelGearMeshDesign':
        '''StraightBevelGearMeshDesign: 'StraightBevelGearMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_904.StraightBevelGearMeshDesign)(self.wrapped.StraightBevelGearMesh) if self.wrapped.StraightBevelGearMesh else None

    @property
    def straight_bevel_gear_ratings(self) -> 'List[_365.StraightBevelGearRating]':
        '''List[StraightBevelGearRating]: 'StraightBevelGearRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelGearRatings, constructor.new(_365.StraightBevelGearRating))
        return value



'''_3003.py

GearSetSteadyStateSynchronousResponseAtASpeed
'''


from mastapy.system_model.part_model.gears import (
    _2239, _2221, _2223, _2227,
    _2229, _2231, _2233, _2236,
    _2242, _2244, _2246, _2248,
    _2249, _2251, _2253, _2255,
    _2259, _2261
)
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _3042
from mastapy._internal.python_net import python_net_import

_GEAR_SET_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed', 'GearSetSteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('GearSetSteadyStateSynchronousResponseAtASpeed',)


class GearSetSteadyStateSynchronousResponseAtASpeed(_3042.SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed):
    '''GearSetSteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    '''

    TYPE = _GEAR_SET_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearSetSteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2239.GearSet':
        '''GearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2239.GearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to GearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_agma_gleason_conical_gear_set(self) -> '_2221.AGMAGleasonConicalGearSet':
        '''AGMAGleasonConicalGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2221.AGMAGleasonConicalGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to AGMAGleasonConicalGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_bevel_differential_gear_set(self) -> '_2223.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2223.BevelDifferentialGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to BevelDifferentialGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_bevel_gear_set(self) -> '_2227.BevelGearSet':
        '''BevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2227.BevelGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to BevelGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_concept_gear_set(self) -> '_2229.ConceptGearSet':
        '''ConceptGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2229.ConceptGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to ConceptGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_conical_gear_set(self) -> '_2231.ConicalGearSet':
        '''ConicalGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2231.ConicalGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to ConicalGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_cylindrical_gear_set(self) -> '_2233.CylindricalGearSet':
        '''CylindricalGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2233.CylindricalGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to CylindricalGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_face_gear_set(self) -> '_2236.FaceGearSet':
        '''FaceGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2236.FaceGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to FaceGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_hypoid_gear_set(self) -> '_2242.HypoidGearSet':
        '''HypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2242.HypoidGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to HypoidGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_klingelnberg_cyclo_palloid_conical_gear_set(self) -> '_2244.KlingelnbergCycloPalloidConicalGearSet':
        '''KlingelnbergCycloPalloidConicalGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2244.KlingelnbergCycloPalloidConicalGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to KlingelnbergCycloPalloidConicalGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_klingelnberg_cyclo_palloid_hypoid_gear_set(self) -> '_2246.KlingelnbergCycloPalloidHypoidGearSet':
        '''KlingelnbergCycloPalloidHypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2246.KlingelnbergCycloPalloidHypoidGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to KlingelnbergCycloPalloidHypoidGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_klingelnberg_cyclo_palloid_spiral_bevel_gear_set(self) -> '_2248.KlingelnbergCycloPalloidSpiralBevelGearSet':
        '''KlingelnbergCycloPalloidSpiralBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2248.KlingelnbergCycloPalloidSpiralBevelGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to KlingelnbergCycloPalloidSpiralBevelGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_planetary_gear_set(self) -> '_2249.PlanetaryGearSet':
        '''PlanetaryGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2249.PlanetaryGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to PlanetaryGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_spiral_bevel_gear_set(self) -> '_2251.SpiralBevelGearSet':
        '''SpiralBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2251.SpiralBevelGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to SpiralBevelGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_straight_bevel_diff_gear_set(self) -> '_2253.StraightBevelDiffGearSet':
        '''StraightBevelDiffGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2253.StraightBevelDiffGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to StraightBevelDiffGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_straight_bevel_gear_set(self) -> '_2255.StraightBevelGearSet':
        '''StraightBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2255.StraightBevelGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to StraightBevelGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_worm_gear_set(self) -> '_2259.WormGearSet':
        '''WormGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2259.WormGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to WormGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_zerol_bevel_gear_set(self) -> '_2261.ZerolBevelGearSet':
        '''ZerolBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2261.ZerolBevelGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to ZerolBevelGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None



'''_2045.py

CycloidalDiscInnerSocket
'''


from mastapy.system_model.connections_and_sockets import _1989
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_DISC_INNER_SOCKET = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets.Cycloidal', 'CycloidalDiscInnerSocket')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalDiscInnerSocket',)


class CycloidalDiscInnerSocket(_1989.InnerShaftSocketBase):
    '''CycloidalDiscInnerSocket

    This is a mastapy class.
    '''

    TYPE = _CYCLOIDAL_DISC_INNER_SOCKET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalDiscInnerSocket.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_5543.py

CycloidalAssemblyCompoundHarmonicAnalysisOfSingleExcitation
'''


from typing import List

from mastapy.system_model.part_model.cycloidal import _2275
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation import _5413
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation.compound import _5598
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_ASSEMBLY_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation.Compound', 'CycloidalAssemblyCompoundHarmonicAnalysisOfSingleExcitation')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalAssemblyCompoundHarmonicAnalysisOfSingleExcitation',)


class CycloidalAssemblyCompoundHarmonicAnalysisOfSingleExcitation(_5598.SpecialisedAssemblyCompoundHarmonicAnalysisOfSingleExcitation):
    '''CycloidalAssemblyCompoundHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    '''

    TYPE = _CYCLOIDAL_ASSEMBLY_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalAssemblyCompoundHarmonicAnalysisOfSingleExcitation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2275.CycloidalAssembly':
        '''CycloidalAssembly: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2275.CycloidalAssembly)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2275.CycloidalAssembly':
        '''CycloidalAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2275.CycloidalAssembly)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5413.CycloidalAssemblyHarmonicAnalysisOfSingleExcitation]':
        '''List[CycloidalAssemblyHarmonicAnalysisOfSingleExcitation]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_5413.CycloidalAssemblyHarmonicAnalysisOfSingleExcitation))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5413.CycloidalAssemblyHarmonicAnalysisOfSingleExcitation]':
        '''List[CycloidalAssemblyHarmonicAnalysisOfSingleExcitation]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_5413.CycloidalAssemblyHarmonicAnalysisOfSingleExcitation))
        return value



'''_1827.py

RollerISOTS162812008Results
'''


from mastapy._internal import constructor
from mastapy.bearings.bearing_results.rolling.iso_rating_results import _1825
from mastapy._internal.python_net import python_net_import

_ROLLER_ISOTS162812008_RESULTS = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling.IsoRatingResults', 'RollerISOTS162812008Results')


__docformat__ = 'restructuredtext en'
__all__ = ('RollerISOTS162812008Results',)


class RollerISOTS162812008Results(_1825.ISOTS162812008Results):
    '''RollerISOTS162812008Results

    This is a mastapy class.
    '''

    TYPE = _ROLLER_ISOTS162812008_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollerISOTS162812008Results.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def basic_dynamic_load_rating_of_a_bearing_lamina_of_the_inner_ring(self) -> 'float':
        '''float: 'BasicDynamicLoadRatingOfABearingLaminaOfTheInnerRing' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BasicDynamicLoadRatingOfABearingLaminaOfTheInnerRing

    @property
    def basic_dynamic_load_rating_of_a_bearing_lamina_of_the_outer_ring(self) -> 'float':
        '''float: 'BasicDynamicLoadRatingOfABearingLaminaOfTheOuterRing' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BasicDynamicLoadRatingOfABearingLaminaOfTheOuterRing

    @property
    def equivalent_load_assuming_line_contacts(self) -> 'float':
        '''float: 'EquivalentLoadAssumingLineContacts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EquivalentLoadAssumingLineContacts



'''_1739.py

LoadedNeedleRollerBearingElement
'''


from mastapy._internal import constructor
from mastapy.bearings.bearing_results.rolling import _1727
from mastapy._internal.python_net import python_net_import

_LOADED_NEEDLE_ROLLER_BEARING_ELEMENT = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'LoadedNeedleRollerBearingElement')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedNeedleRollerBearingElement',)


class LoadedNeedleRollerBearingElement(_1727.LoadedCylindricalRollerBearingElement):
    '''LoadedNeedleRollerBearingElement

    This is a mastapy class.
    '''

    TYPE = _LOADED_NEEDLE_ROLLER_BEARING_ELEMENT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedNeedleRollerBearingElement.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def sliding_power_loss_from_macro_sliding_due_to_roller_skew(self) -> 'float':
        '''float: 'SlidingPowerLossFromMacroSlidingDueToRollerSkew' is the original name of this property.'''

        return self.wrapped.SlidingPowerLossFromMacroSlidingDueToRollerSkew

    @sliding_power_loss_from_macro_sliding_due_to_roller_skew.setter
    def sliding_power_loss_from_macro_sliding_due_to_roller_skew(self, value: 'float'):
        self.wrapped.SlidingPowerLossFromMacroSlidingDueToRollerSkew = float(value) if value else 0.0

    @property
    def sliding_power_loss_from_hysteresis(self) -> 'float':
        '''float: 'SlidingPowerLossFromHysteresis' is the original name of this property.'''

        return self.wrapped.SlidingPowerLossFromHysteresis

    @sliding_power_loss_from_hysteresis.setter
    def sliding_power_loss_from_hysteresis(self, value: 'float'):
        self.wrapped.SlidingPowerLossFromHysteresis = float(value) if value else 0.0

    @property
    def sliding_power_loss_roller_cage_moment_component(self) -> 'float':
        '''float: 'SlidingPowerLossRollerCageMomentComponent' is the original name of this property.'''

        return self.wrapped.SlidingPowerLossRollerCageMomentComponent

    @sliding_power_loss_roller_cage_moment_component.setter
    def sliding_power_loss_roller_cage_moment_component(self, value: 'float'):
        self.wrapped.SlidingPowerLossRollerCageMomentComponent = float(value) if value else 0.0

    @property
    def sliding_power_loss_roller_cage_radial_component(self) -> 'float':
        '''float: 'SlidingPowerLossRollerCageRadialComponent' is the original name of this property.'''

        return self.wrapped.SlidingPowerLossRollerCageRadialComponent

    @sliding_power_loss_roller_cage_radial_component.setter
    def sliding_power_loss_roller_cage_radial_component(self, value: 'float'):
        self.wrapped.SlidingPowerLossRollerCageRadialComponent = float(value) if value else 0.0

    @property
    def sliding_power_loss_roller_cage_axial_component(self) -> 'float':
        '''float: 'SlidingPowerLossRollerCageAxialComponent' is the original name of this property.'''

        return self.wrapped.SlidingPowerLossRollerCageAxialComponent

    @sliding_power_loss_roller_cage_axial_component.setter
    def sliding_power_loss_roller_cage_axial_component(self, value: 'float'):
        self.wrapped.SlidingPowerLossRollerCageAxialComponent = float(value) if value else 0.0
